nsca_corners: Empty corners of a necessary-and-sufficient statement

View source: R/corners.R

nsca_cornersR Documentation

Empty corners of a necessary-and-sufficient statement

Description

Returns the two physically empty scatter-plot corners implied by a necessary-and-sufficient statement. The necessity corner is always the diagonal opposite of the sufficiency corner.

Usage

nsca_corners(direction = "HH")

Arguments

direction

One or more of "HH", "LH", "HL", "LL". The first letter refers to the level of the condition and the second to the level of the outcome.

Value

A data frame with the necessity and sufficiency corners and the side of the point cloud each frontier bounds.

Examples

nsca_corners("HH")
nsca_corners(c("HH", "LL"))

NSCA documentation built on Oct. 10, 2026, 5:08 p.m.