| nsca_corners | R Documentation |
Returns the two physically empty scatter-plot corners implied by a necessary-and-sufficient statement. The necessity corner is always the diagonal opposite of the sufficiency corner.
nsca_corners(direction = "HH")
direction |
One or more of |
A data frame with the necessity and sufficiency corners and the side of the point cloud each frontier bounds.
nsca_corners("HH")
nsca_corners(c("HH", "LL"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.