| nsca_terms | R Documentation |
A machine-readable glossary linking the vocabulary of the condition analysis
in degree framework to the names this package uses. Names retired along the
way are listed by nsca_legacy_names().
nsca_terms()
A data frame with one row per term.
nsca_legacy_names(), nsca_direction_map(), nsca_table()
nsca_terms()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.